package sun.util.locale.provider;

import java.util.MissingResourceException;
import java.io.IOException;
import java.text.BreakIterator;
import java.util.Locale;
import java.util.Set;
import java.text.spi.BreakIteratorProvider;

public class BreakIteratorProviderImpl extends BreakIteratorProvider implements AvailableLanguageTags
{
    private static final int CHARACTER_INDEX = 0;
    private static final int WORD_INDEX = 1;
    private static final int LINE_INDEX = 2;
    private static final int SENTENCE_INDEX = 3;
    private final LocaleProviderAdapter.Type type;
    private final Set<String> langtags;
    
    public BreakIteratorProviderImpl(LocaleProviderAdapter.Type type, Set<String> langtags) {
        this.type = type;
        this.langtags = langtags;
    }
    
    @Override
    public Locale[] getAvailableLocales() {
        return LocaleProviderAdapter.toLocaleArray(this.langtags);
    }
    
    @Override
    public BreakIterator getWordInstance(Locale locale) {
        return this.getBreakInstance(locale, 1, "WordData", "WordDictionary");
    }
    
    @Override
    public BreakIterator getLineInstance(Locale locale) {
        return this.getBreakInstance(locale, 2, "LineData", "LineDictionary");
    }
    
    @Override
    public BreakIterator getCharacterInstance(Locale locale) {
        return this.getBreakInstance(locale, 0, "CharacterData", "CharacterDictionary");
    }
    
    @Override
    public BreakIterator getSentenceInstance(Locale locale) {
        return this.getBreakInstance(locale, 3, "SentenceData", "SentenceDictionary");
    }
    
    private BreakIterator getBreakInstance(Locale locale, int n, String s, String s2) {
        if (locale == null) {
            throw new NullPointerException();
        }
        LocaleResources localeResources = LocaleProviderAdapter.forJRE().getLocaleResources(locale);
        String[] array = (String[])(String[])localeResources.getBreakIteratorInfo("BreakIteratorClasses");
        String s3 = (String)localeResources.getBreakIteratorInfo(s);
        try {
            String s4 = array[n];
            int n2 = -1;
            switch (s4.hashCode()) {
                case 1909671382: {
                    if (s4.equals("RuleBasedBreakIterator")) {
                        n2 = 0;
                        break;
                    }
                    break;
                }
                case 1249121520: {
                    if (s4.equals("DictionaryBasedBreakIterator")) {
                        n2 = 1;
                        break;
                    }
                    break;
                }
            }
            switch (n2) {
                case 0: {
                    return new RuleBasedBreakIterator(s3);
                }
                case 1: {
                    return new DictionaryBasedBreakIterator(s3, (String)localeResources.getBreakIteratorInfo(s2));
                }
                default: {
                    throw new IllegalArgumentException("Invalid break iterator class \"" + array[n] + "\"");
                }
            }
        }
        catch (IOException | MissingResourceException | IllegalArgumentException cause) {
            throw new InternalError(cause.toString(), cause);
        }
    }
    
    @Override
    public Set<String> getAvailableLanguageTags() {
        return this.langtags;
    }
    
    @Override
    public boolean isSupportedLocale(Locale locale) {
        return LocaleProviderAdapter.isSupportedLocale(locale, this.type, this.langtags);
    }
}
